@@ -2,6 +2,7 @@
   This file is part of Lokalize
 
   Copyright (C) 2009 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -24,7 +25,7 @@
 #ifndef STATE_H
 #define STATE_H
 
-///@see @link http://docs.oasis-open.org/xliff/v1.2/os/xliff-core.html#state
+///@see http://docs.oasis-open.org/xliff/v1.2/os/xliff-core.html#state
 enum TargetState {
     New,
     NeedsTranslation,
