@@ -128,7 +128,7 @@ QString convertToHtml(QString str, bool italics)
     str = Qt::convertFromPlainText(str); //FIXME use another routine (this has bugs)
 
     if (italics)
-        str = "<p><i>" % QString::fromRawData(str.unicode() + 3, str.length() - 3 - 4) % "</i></p>";
+        str = "<p><i>" + QString::fromRawData(str.unicode() + 3, str.length() - 3 - 4) + "</i></p>";
 
     return str;
 }
