@@ -111,9 +111,9 @@ void TermLabel::setText(const QString& term, const QByteArray& entryId, bool cap
     m_capFirst = capFirst;
 
     static const QString n = QStringLiteral("  \n  ");
-    QLabel::setText(QString(term + QString(m_action ? QString(QStringLiteral(" [") % m_action->shortcut().toString(QKeySequence::NativeText) % QStringLiteral("]  \n  ")) : n) //m_shortcut
-                            % Project::instance()->glossary()->terms(m_entryId, Project::instance()->targetLangCode()).join(n)
-                            % n));
+    QLabel::setText(QString(term + QString(m_action ? QString(QStringLiteral(" [") + m_action->shortcut().toString(QKeySequence::NativeText) + QStringLiteral("]  \n  ")) : n) //m_shortcut
+                            + Project::instance()->glossary()->terms(m_entryId, Project::instance()->targetLangCode()).join(n)
+                            + n));
 }
 
 
