@@ -53,7 +53,6 @@
 #include <QTime>
 #include <QSplitter>
 #include <QTextBrowser>
-#include <QSignalMapper>
 #include <QTimer>
 
 // #include <QShortcutEvent>
@@ -107,13 +106,10 @@ void WebQueryView::initLater()
     m_browser->setToolTip(i18nc("@info:tooltip", "Double-click any word to insert it into translation"));
 
 
-    QSignalMapper* signalMapper = new QSignalMapper(this);
     int i = m_actions.size();
     while (--i >= 0) {
-        connect(m_actions.at(i), &QAction::triggered, signalMapper, QOverload<>::of(&QSignalMapper::map));
-        signalMapper->setMapping(m_actions.at(i), i);
+        connect(m_actions.at(i), &QAction::triggered, this, [this, i] { slotUseSuggestion(i); });
     }
-    connect(signalMapper, QOverload<int>::of(&QSignalMapper::mapped), this, &WebQueryView::slotUseSuggestion);
     connect(m_browser, &QTextBrowser::selectionChanged, this, &WebQueryView::slotSelectionChanged);
 
 }
