@@ -2,6 +2,7 @@
   This file is part of Lokalize
 
   Copyright (C) 2007-2014 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -63,6 +64,7 @@ public:
         Q_UNUSED(block);
         return true;
     }
+    void insertPlainTextWithCursorCheck(const QString &text);
 
 public slots:
     void reflectApprovementState();
